pub struct Basic {
pub client: Client,
}requests only.Fields
client: ClientImplementations
Sourceimpl Basic
impl Basic
Sourcepub async fn get_crm_v_3_objects_tickets_ticket_id_get_by_id<'a>(
&'a self,
archived: Option<bool>,
associations: Option<Vec<String>>,
id_property: Option<String>,
properties: Option<Vec<String>>,
properties_with_history: Option<Vec<String>>,
ticket_id: &'a str,
) -> Result<SimplePublicObjectWithAssociations, Error>
pub async fn get_crm_v_3_objects_tickets_ticket_id_get_by_id<'a>( &'a self, archived: Option<bool>, associations: Option<Vec<String>>, id_property: Option<String>, properties: Option<Vec<String>>, properties_with_history: Option<Vec<String>>, ticket_id: &'a str, ) -> Result<SimplePublicObjectWithAssociations, Error>
Read
Read an Object identified by {ticketId}. {ticketId} refers to the internal object ID by default, or optionally any unique property value as specified by the idProperty query param. Control what is returned via the properties query param.
Parameters:
archived: Option<bool>: Whether to return only results that have been archived.associations: Option<Vec<String>>: A comma separated list of object types to retrieve associated IDs for. If any of the specified associations do not exist, they will be ignored.id_property: Option<String>: The name of a property whose values are unique for this object typeproperties: Option<Vec<String>>: A comma separated list of the properties to be returned in the response. If any of the specified properties are not present on the requested object(s), they will be ignored.properties_with_history: Option<Vec<String>>: A comma separated list of the properties to be returned along with their history of previous values. If any of the specified properties are not present on the requested object(s), they will be ignored.ticket_id: &'astr(required)
async fn example_basic_get_crm_v_3_objects_tickets_ticket_id_get_by_id() -> anyhow::Result<()> {
let client = hubspot_tickets::Client::new_from_env();
let result: hubspot_tickets::types::SimplePublicObjectWithAssociations = client
.basic()
.get_crm_v_3_objects_tickets_ticket_id_get_by_id(
Some(true),
Some(vec!["some-string".to_string()]),
Some("some-string".to_string()),
Some(vec!["some-string".to_string()]),
Some(vec!["some-string".to_string()]),
"some-string",
)
.await?;
println!("{:?}", result);
Ok(())
}Sourcepub async fn delete_crm_v_3_objects_tickets_ticket_id_archive<'a>(
&'a self,
ticket_id: &'a str,
) -> Result<(), Error>
pub async fn delete_crm_v_3_objects_tickets_ticket_id_archive<'a>( &'a self, ticket_id: &'a str, ) -> Result<(), Error>
Archive
Move an Object identified by {ticketId} to the recycling bin.
Parameters:
ticket_id: &'astr(required)
async fn example_basic_delete_crm_v_3_objects_tickets_ticket_id_archive() -> anyhow::Result<()> {
let client = hubspot_tickets::Client::new_from_env();
client
.basic()
.delete_crm_v_3_objects_tickets_ticket_id_archive("some-string")
.await?;
Ok(())
}Sourcepub async fn patch_crm_v_3_objects_tickets_ticket_id_update<'a>(
&'a self,
id_property: Option<String>,
ticket_id: &'a str,
body: &SimplePublicObjectInput,
) -> Result<SimplePublicObject, Error>
pub async fn patch_crm_v_3_objects_tickets_ticket_id_update<'a>( &'a self, id_property: Option<String>, ticket_id: &'a str, body: &SimplePublicObjectInput, ) -> Result<SimplePublicObject, Error>
Update
Perform a partial update of an Object identified by {ticketId}. {ticketId} refers to the internal object ID by default, or optionally any unique property value as specified by the idProperty query param. Provided property values will be overwritten. Read-only and non-existent properties will be ignored. Properties values can be cleared by passing an empty string.
Parameters:
id_property: Option<String>: The name of a property whose values are unique for this object typeticket_id: &'astr(required)
async fn example_basic_patch_crm_v_3_objects_tickets_ticket_id_update() -> anyhow::Result<()> {
let client = hubspot_tickets::Client::new_from_env();
let result: hubspot_tickets::types::SimplePublicObject = client
.basic()
.patch_crm_v_3_objects_tickets_ticket_id_update(
Some("some-string".to_string()),
"some-string",
&hubspot_tickets::types::SimplePublicObjectInput {
properties: std::collections::HashMap::from([(
"some-key".to_string(),
"some-string".to_string(),
)]),
},
)
.await?;
println!("{:?}", result);
Ok(())
}Sourcepub async fn get_crm_v_3_objects_tickets_get_page<'a>(
&'a self,
after: Option<String>,
archived: Option<bool>,
associations: Option<Vec<String>>,
limit: Option<i32>,
properties: Option<Vec<String>>,
properties_with_history: Option<Vec<String>>,
) -> Result<CollectionResponseSimplePublicObjectWithAssociationsForwardPaging, Error>
pub async fn get_crm_v_3_objects_tickets_get_page<'a>( &'a self, after: Option<String>, archived: Option<bool>, associations: Option<Vec<String>>, limit: Option<i32>, properties: Option<Vec<String>>, properties_with_history: Option<Vec<String>>, ) -> Result<CollectionResponseSimplePublicObjectWithAssociationsForwardPaging, Error>
List
Read a page of tickets. Control what is returned via the properties query param.
Parameters:
after: Option<String>: The paging cursor token of the last successfully read resource will be returned as thepaging.next.afterJSON property of a paged response containing more results.archived: Option<bool>: Whether to return only results that have been archived.associations: Option<Vec<String>>: A comma separated list of object types to retrieve associated IDs for. If any of the specified associations do not exist, they will be ignored.limit: Option<i32>: The maximum number of results to display per page.properties: Option<Vec<String>>: A comma separated list of the properties to be returned in the response. If any of the specified properties are not present on the requested object(s), they will be ignored.properties_with_history: Option<Vec<String>>: A comma separated list of the properties to be returned along with their history of previous values. If any of the specified properties are not present on the requested object(s), they will be ignored. Usage of this parameter will reduce the maximum number of objects that can be read by a single request.
async fn example_basic_get_crm_v_3_objects_tickets_get_page() -> anyhow::Result<()> {
let client = hubspot_tickets::Client::new_from_env();
let result: hubspot_tickets::types::CollectionResponseSimplePublicObjectWithAssociationsForwardPaging =
client
.basic()
.get_crm_v_3_objects_tickets_get_page(
Some("some-string".to_string()),
Some(true),
Some(vec!["some-string".to_string()]),
Some(4 as i32),
Some(vec!["some-string".to_string()]),
Some(vec!["some-string".to_string()]),
)
.await?;
println!("{:?}", result);
Ok(())
}Sourcepub async fn post_crm_v_3_objects_tickets_create<'a>(
&'a self,
body: &SimplePublicObjectInputForCreate,
) -> Result<SimplePublicObject, Error>
pub async fn post_crm_v_3_objects_tickets_create<'a>( &'a self, body: &SimplePublicObjectInputForCreate, ) -> Result<SimplePublicObject, Error>
Create
Create a ticket with the given properties and return a copy of the object, including the ID. Documentation and examples for creating standard tickets is provided.
async fn example_basic_post_crm_v_3_objects_tickets_create() -> anyhow::Result<()> {
let client = hubspot_tickets::Client::new_from_env();
let result: hubspot_tickets::types::SimplePublicObject = client
.basic()
.post_crm_v_3_objects_tickets_create(&hubspot_tickets::types::SimplePublicObjectInputForCreate {
associations: vec![hubspot_tickets::types::PublicAssociationsForObject {
types: vec![hubspot_tickets::types::AssociationSpec {
association_category: hubspot_tickets::types::AssociationCategory::UserDefined,
association_type_id: 4 as i32,
}],
to: hubspot_tickets::types::PublicObjectId {
id: "some-string".to_string(),
},
}],
properties: std::collections::HashMap::from([(
"some-key".to_string(),
"some-string".to_string(),
)]),
})
.await?;
println!("{:?}", result);
Ok(())
}Trait Implementations