pub struct BatchInputSimplePublicObjectBatchInput {
pub inputs: Vec<SimplePublicObjectBatchInput>,
}Fields
inputs: Vec<SimplePublicObjectBatchInput>Trait Implementations
Sourceimpl Clone for BatchInputSimplePublicObjectBatchInput
impl Clone for BatchInputSimplePublicObjectBatchInput
Sourcefn clone(&self) -> BatchInputSimplePublicObjectBatchInput
fn clone(&self) -> BatchInputSimplePublicObjectBatchInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BatchInputSimplePublicObjectBatchInput
impl<'de> Deserialize<'de> for BatchInputSimplePublicObjectBatchInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BatchInputSimplePublicObjectBatchInput
impl JsonSchema for BatchInputSimplePublicObjectBatchInput
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BatchInputSimplePublicObjectBatchInput
impl PartialEq for BatchInputSimplePublicObjectBatchInput
Sourcefn eq(&self, other: &BatchInputSimplePublicObjectBatchInput) -> bool
fn eq(&self, other: &BatchInputSimplePublicObjectBatchInput) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BatchInputSimplePublicObjectBatchInput
Sourceimpl Tabled for BatchInputSimplePublicObjectBatchInput
Available on crate feature tabled only.
impl Tabled for BatchInputSimplePublicObjectBatchInput
Available on crate feature
tabled only.Auto Trait Implementations
impl Freeze for BatchInputSimplePublicObjectBatchInput
impl RefUnwindSafe for BatchInputSimplePublicObjectBatchInput
impl Send for BatchInputSimplePublicObjectBatchInput
impl Sync for BatchInputSimplePublicObjectBatchInput
impl Unpin for BatchInputSimplePublicObjectBatchInput
impl UnsafeUnpin for BatchInputSimplePublicObjectBatchInput
impl UnwindSafe for BatchInputSimplePublicObjectBatchInput